@@ -252,6 +252,7 @@ class LLSDNotationUnitTest(unittest.TestCase):
         valid_date_notation_no_float = 'd"2006-02-01T14:29:53Z"'
         valid_date_notation_zero_seconds = 'd"2006-02-01T14:29:00Z"'
         valid_date_notation_filled = 'd"2006-02-01T14:29:05Z"'
+        valid_date_19th_century = 'd"1833-02-01T00:00:00Z"'
 
         blank_date_notation = 'd""'
 
@@ -259,6 +260,7 @@ class LLSDNotationUnitTest(unittest.TestCase):
         python_valid_date_no_float = datetime(2006, 2, 1, 14, 29, 53)
         python_valid_date_zero_seconds = datetime(2006, 2, 1, 14, 29, 0)
         python_valid_date_filled = datetime(2006, 2, 1, 14, 29, 05)
+        python_valid_date_19th_century = datetime(1833,2,1)
 
         python_blank_date = datetime(1970, 1, 1)
 
@@ -273,6 +275,8 @@ class LLSDNotationUnitTest(unittest.TestCase):
 
         self.assertNotationRoundtrip(python_valid_date_filled,
                                        valid_date_notation_filled)
+        self.assertNotationRoundtrip(python_valid_date_19th_century,
+                                        valid_date_19th_century)
 
         self.assertEqual(python_blank_date, self.llsd.parse(blank_date_notation))
 
@@ -329,14 +333,34 @@ class LLSDNotationUnitTest(unittest.TestCase):
         string_data2 = """
                 <p>"Take some more <a href="/wiki/Tea" title="Tea">tea</a> ," the March Hare said to Alice, very earnestly.</p>
                 """
-        python_binary1 = string_data1
-        python_binary2 = string_data2
+        python_binary1 = llsd.binary(string_data1)
+        python_binary2 = llsd.binary(string_data2)
         
-        notation1 = 'b64' + '"' + base64.b64encode(string_data1) + '"'
-        notation2 = 'b64' + '"' + base64.b64encode(string_data2) + '"'
+        notation1 = 'b64' + '"' + base64.b64encode(string_data1).strip() + '"'
+        notation2 = 'b64' + '"' + base64.b64encode(string_data2).strip() + '"'
+        notation3 = 'b16' + '"' + base64.b16encode(string_data1).strip() + '"'
+        notation4 = 'b16' + '"' + base64.b16encode(string_data2).strip() + '"'
+        notation5 = 'b85' + '"<~EHPu*CER),Dg-(AAoDo;+T~>"'
+        notation6 = 'b85' + '"<~4E*J.<+0QR+EMI<AKYi.Eb-@U@3B6(AS+(L06_,GBeNFs@3Qh9Bln0&4X*j:@3RmWARR\S@6Peb+s:u@AKX]UEarc*87?OM+ELt*A0>u4+@0gX@q@26G%G]>+D"u%DImm2Cj@Wq05s)~>"'
 
         self.assertNotationRoundtrip(python_binary1, notation1, True)
         self.assertNotationRoundtrip(python_binary2, notation2, True)
+        self.assertNotationRoundtrip(python_binary1, notation3, True)
+        self.assertNotationRoundtrip(python_binary2, notation4, True)
+        self.assertRaises(llsd.LLSDParseError, self.llsd.parse, notation5)
+        self.assertRaises(llsd.LLSDParseError, self.llsd.parse, notation6)
+
+    '''
+    def testProblemMap(self):
+        """
+        This is some data that the fuzzer generated that caused a parse error
+        """
+        string_data = "{'$g7N':!,'3r=h':true,'\xe8\x88\xbc\xe9\xa7\xb9\xe1\xb9\xa6\xea\xb3\x95\xe0\xa8\xb3\xe1\x9b\x84\xef\xb2\xa7\xe8\x8f\x99\xe8\x94\xa0\xe9\x90\xb9\xe6\x88\x9b\xe0\xaf\x84\xe8\xb8\xa2\xe4\x94\x83\xea\xb5\x8b\xed\x8c\x8a\xe5\xb5\x97':'\xe6\xbb\xa6\xe3\xbf\x88\xea\x9b\x82\xea\x9f\x8d\xee\xbb\xba\xe4\xbf\x87\xe3\x8c\xb5\xe3\xb2\xb0\xe7\x90\x91\xee\x8f\xab\xee\x81\xa5\xea\x94\x98'}"
+        python_obj = {}
+
+        import pdb; pdb.set_trace()
+        self.assertNotationRoundtrip(python_obj, string_data, True)
+    '''
 
     def testNotationOfAllTypes(self):
         """
@@ -547,6 +571,21 @@ class LLSDXMLUnitTest(unittest.TestCase):
         if not sys.platform.lower().startswith('win'):
             self.assert_(llsd.cllsd is not None)
 
+    def testStrConversion(self):
+        """
+        Test the __str__() conversion on the LLSD class
+        """
+        some_xml ="\
+<?xml version=\"1.0\" ?>\
+<llsd>\
+<integer>1234</integer>\
+</llsd>"
+
+        c = llsd.LLSD(llsd.parse_xml(some_xml))
+        out_xml = str(c)
+
+        self.assertEqual(some_xml, out_xml)
+
     def testInteger(self):
         """
         Test the parse and serializatioin of input type : integer
@@ -743,17 +782,26 @@ class LLSDXMLUnitTest(unittest.TestCase):
 <date />\
 </llsd>"
 
+        before_19th_century_date = "\
+<?xml version=\"1.0\" ?>\
+<llsd>\
+<date>1853-02-01T00:00:00Z</date>\
+</llsd>"
 
         python_valid_date = datetime(2006, 2, 1, 14, 29, 53, 460000)
         python_valid_date_no_fractional = datetime(2006, 2, 1, 14, 29, 53)
         python_valid_date_filled = datetime(2006, 2, 1, 14, 29, 05)
+        python_19th_century_date = datetime(1853, 2, 1)
         python_blank_date = datetime(1970, 1, 1)
+        
         self.assertXMLRoundtrip(python_valid_date,
                                   valid_date_xml)
         self.assertXMLRoundtrip(python_valid_date_no_fractional,
                                   valid_date_xml_no_fractional)
         self.assertXMLRoundtrip(python_valid_date_filled,
                                   valid_date_xml_filled)
+        self.assertXMLRoundtrip(python_19th_century_date,
+                                  before_19th_century_date)
         self.assertEqual(python_blank_date, self.llsd.parse(blank_date_xml))
 
     def testArray(self):
@@ -1756,17 +1804,25 @@ class LLSDPythonXMLUnitTest(unittest.TestCase):
 <date />\
 </llsd>"
 
+        before_19th_century_date = "\
+<?xml version=\"1.0\" ?>\
+<llsd>\
+<date>1853-02-01T00:00:00Z</date>\
+</llsd>"
 
         python_valid_date = datetime(2006, 2, 1, 14, 29, 53, 460000)
         python_valid_date_no_fractional = datetime(2006, 2, 1, 14, 29, 53)
         python_valid_date_filled = datetime(2006, 2, 1, 14, 29, 05)
         python_blank_date = datetime(1970, 1, 1)
+        python_19th_century_date = datetime(1853, 2, 1)
         self.assertXMLRoundtrip(python_valid_date,
                                   valid_date_xml)
         self.assertXMLRoundtrip(python_valid_date_no_fractional,
                                   valid_date_xml_no_fractional)
         self.assertXMLRoundtrip(python_valid_date_filled,
                                   valid_date_xml_filled)
+        self.assertXMLRoundtrip(python_19th_century_date,
+                                before_19th_century_date)
         self.assertEqual(python_blank_date, self.llsd.parse(blank_date_xml))
 
     def testArray(self):
@@ -2316,5 +2372,27 @@ class LLSDFuzzTest(unittest.TestCase):
             return s
         self.fuzz_roundtrip_base(llsd.format_xml, normalize)
         
+class Regression(unittest.TestCase):
+    '''
+    Regression tests.
+    '''
+
+    def test_no_newline_in_base64_notation(self):
+        n = llsd.format_notation(llsd.binary('\0'*100))
+        self.assertEqual(n.replace('\n', ''), n)
+
+    def test_no_newline_in_base64_xml(self):
+        n = llsd.format_xml(llsd.binary('\0'*100))
+        self.assertEqual(n.replace('\n', ''), n)
+
+    def test_no_newline_in_base64_xml_sans_cllsd(self):
+        try:
+            real_cllsd = llsd.cllsd
+            llsd.cllsd = None
+            n = llsd.format_xml(llsd.binary('\0'*100))
+        finally:
+            llsd.cllsd = real_cllsd
+        self.assertEqual(n.replace('\n', ''), n)
+
 if __name__ == '__main__':
     unittest.main()
